# DSS simulation
# Written by Zhao Cheng, Itasca Consulting Group, Inc.

import numpy as np
import matplotlib.pyplot as plt
from matplotlib import gridspec

inidict =  {500 : [0.960, 0.886, 0.810], 
            100 : [0.996, 0.917, 0.831]}
            
qylist = {100 : 300, 500 : 1500}

plt.close("all")

for pm0, e0list in inidict.items() :  
    f = plt.figure(figsize=(7,10))
    gs = gridspec.GridSpec(2, 1, height_ratios=[1, 1])
    pngfile =  'tri_cp_' + 'p_' + '{:3.0f}'.format(pm0) + '.png'
    
    for e0 in e0list :
        outfile = 'tri_cp_' + 'p_' + '{:3.0f}'.format(pm0) + '_e_' + '{:3.0f}'.format(e0*1000.0) 
        txtfile =  outfile + '.txt'
        
        q, a, v = np.loadtxt(txtfile, usecols=(1,3,4), skiprows=2, unpack=True) 

        ax = plt.subplot(gs[0, 0])
        plt.plot(v, q, linewidth=2)
        plt.xlabel('Void ratio, $e$', size=16)
        plt.ylabel('Deviatoric stress, $q$ (kPa)', size=16)
        plt.axis([0.75, 1.05, 0, qylist[pm0]])
        
        ax = plt.subplot(gs[1, 0])
        plt.plot([-100.0*x for x in a], q, linewidth=2, label = '$e_{0}$ = ' + '{:5.3f}'.format(e0))
        plt.xlabel('Axial strain, $\\epsilon_1$ (%)', size=16)
        plt.ylabel('Deviatoric stress, $q$ (kPa)', size=16)
        plt.axis([0, 30, 0, qylist[pm0]]) 
        plt.legend(loc = 'lower center', numpoints = 1, fontsize = 16)
        
    plt.savefig(pngfile)

plt.show()        