# DSS simulation
# Written by Zhao Cheng, Itasca Consulting Group, Inc.

import numpy as np
import matplotlib.pyplot as plt
from matplotlib import gridspec

e0list = [0.735, 0.833, 0.907]
pmlist = [1e2, 1e3, 2e3, 3e3]

qylist = {0.735 : 5000,
          0.833 : 2500,
          0.907 : 1200}

plt.close("all")
#f = plt.figure(figsize=(7,10))
#gs = gridspec.GridSpec(2, 1, height_ratios=[1, 1])
#plt.hold(True)

for e0 in e0list : 
    f = plt.figure(figsize=(7,10))
    gs = gridspec.GridSpec(2, 1, height_ratios=[1, 1])
    pngfile =  'tri_cp_' + 'e_' + '{:3.0f}'.format(e0*1000.0) + '.png'
    #plt.suptitle('e = ' + '{:5.3f}'.format(e0))
    for pm0 in pmlist :
        outfile = 'tri_cp_' + 'e_' + '{:3.0f}'.format(e0*1000.0) + '_p_' + '{:04.0f}'.format(pm0)
        txtfile =  outfile + '.txt'
        
        q, p, a = np.loadtxt(txtfile, usecols=(1,2,3), skiprows=2, unpack=True) 
        
        ax = plt.subplot(gs[0, 0])
        plt.plot(p, q, label='$p_0$ = '+'{: 4d}'.format(int(pm0))+' kPa', linewidth=2)
        plt.xlabel('Effective mean stress, $p$ (kPa)', size=16)
        plt.ylabel('Deviatoric stress, $q$ (kPa)', size=16)
        plt.axis([0, 3.3e3, 0, qylist[e0]])
        plt.legend(loc = 'upper left', numpoints = 1, fontsize = 12)

        ax = plt.subplot(gs[1, 0])
        plt.plot([-100.0*x for x in a], q, linewidth=2)
        plt.xlabel('Axial stress, $\\epsilon_1$ (%)', size=16)
        plt.ylabel('Deviatoric stress, $q$ (kPa)', size=16)
        plt.axis([0, 30, 0, qylist[e0]])
    plt.savefig(pngfile)

plt.show()        